==> dnsutl-1.6.tar.gz: dnsutl-1.6/etc/Makefi.file.sh <==
#!/bin/sh
#
#	dnsutl - utilities to make DNS easier to configure
#	Copyright (C) 1995, 1999 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: shell script to generate Makefile fragment for each source file
#
case $# in
2 | 3)
	;;
*)
	echo "usage: $0 filename resolved-filename" 1>&2
	exit 1
	;;
esac
file="$1"
rfn="$2"
depfile="$3"

case $file in

*/*.y)
	root=`basename $file .y`
	stem=`echo $file | sed 's/\.y$//'`
	dir=`echo $file | sed 's|/.*||'`

	case $file in
	cook/parse.y)
		numconf="1 shift/reduce"
		;;
	cooktime/date.y)
		numconf="8 shift/reduce"
		;;
	make2cook/gram.y)
		numconf="1 shift/reduce"
		;;
	*)
		numconf="no"
		;;
	esac

	yy=`echo $stem | sed -e 's|^[^/]*/||' -e 's|[^a-zA-Z0-9]|_|g'`
	echo ""
	echo "${stem}.gen.c ${stem}.gen.h: $file"
	echo "	@echo Expect $numconf conflicts:"
	echo "	\$(YACC) -d $file"
	echo "	sed -e 's/[yY][yY]/${yy}_/g' -e '/#include.<stdio.h>/d' y.tab.c > ${stem}.gen.c"
	echo "	sed -e 's/[yY][yY]/${yy}_/g' y.tab.h > ${stem}.gen.h"
	echo "	rm y.tab.c y.tab.h"

	if [ -n "$depfile" -a -r "$depfile" ]; then
		dep=`cat $depfile`
	fi

	echo ""
	echo "${stem}.gen.\$(OBJEXT): ${stem}.gen.c" $dep
	echo "	\$(CC) \$(CPPFLAGS) \$(CFLAGS) -I$dir -Icommon -c ${stem}.gen.c"
	echo "	mv ${root}.gen.\$(OBJEXT) \$@"
	;;

*/*.c)
	root=`basename $file .c`
	stem=`echo $file | sed 's/\.c$//'`
	dir=`echo $file | sed 's|/.*||'`

	if [ -n "$depfile" -a -r "$depfile" ]; then
		dep=`cat $depfile`
	fi

	if [ ${root} = option ]
	then
		libdir="-D'LIBDIR=\"\$(libdir)\"'"
	fi

	echo ""
	echo "${stem}.\$(OBJEXT): $file" $dep
	echo "	\$(CC) \$(CPPFLAGS) \$(CFLAGS)" $libdir "-I$dir -Icommon -c $file"
	echo "	mv ${root}.\$(OBJEXT) \$@"
	;;

man1/*.1)
	root=`basename $file .1`
	echo ""
	echo "man1/$root.h: $file etc/txt2c.awk"
	echo "	awk -f etc/txt2c.awk $file > \$@"

	echo ""
	echo "\$(mandir)/man1/$root.1: $file man1/.mandir"
	echo "	\$(SOELIM) -Iman1 $file > tmp"
	echo "	\$(INSTALL_DATA) tmp \$@"
	echo "	@rm tmp"
	;;

man1/*.so)
	root=`basename $file .so`
	echo ""
	echo "man1/$root.h: $file etc/txt2c.awk"
	echo "	awk -f etc/txt2c.awk $file > \$@"
	;;

test/*/*)
	root=`basename $file .sh`
	echo ""
	echo "$root: $file all"
	echo "	\$(SH) $file"
	;;

*)
	;;
esac
exit 0

==> dnsutl-1.7.tar.gz: dnsutl-1.7/etc/Makefi.file.sh <==
#!/bin/sh
#
#	dnsutl - utilities to make DNS easier to configure
#	Copyright (C) 1995, 1999, 2004 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: shell script to generate Makefile fragment for each source file
#
case $# in
2 | 3)
	;;
*)
	echo "usage: $0 filename resolved-filename" 1>&2
	exit 1
	;;
esac
file="$1"
rfn="$2"
depfile="$3"

case $file in

*/*.y)
	root=`basename $file .y`
	stem=`echo $file | sed 's/\.y$//'`
	dir=`echo $file | sed 's|/.*||'`

	case $file in
	cook/parse.y)
		numconf="1 shift/reduce"
		;;
	cooktime/date.y)
		numconf="8 shift/reduce"
		;;
	make2cook/gram.y)
		numconf="1 shift/reduce"
		;;
	*)
		numconf="no"
		;;
	esac

	yy=`echo $stem | sed -e 's|^[^/]*/||' -e 's|[^a-zA-Z0-9]|_|g'`
	echo ""
	echo "${stem}.gen.c ${stem}.gen.h: $file"
	echo "	@echo Expect $numconf conflicts:"
	echo "	\$(YACC) -d $file"
	echo "	sed -e 's/[yY][yY]/${yy}_/g'" \
		"-e '/#include.<stdio.h>/d'" \
		"-e '/#include.<stddef.h>/d'" \
		"-e '/#include.<stdlib.h>/d'" \
		"y.tab.c > ${stem}.gen.c"
	echo "	sed -e 's/[yY][yY]/${yy}_/g' y.tab.h > ${stem}.gen.h"
	echo "	rm y.tab.c y.tab.h"

	if [ -n "$depfile" -a -r "$depfile" ]; then
		dep=`cat $depfile`
	fi

	echo ""
	echo "${stem}.gen.\$(OBJEXT): ${stem}.gen.c" $dep
	echo "	\$(CC) \$(CPPFLAGS) \$(CFLAGS) -I$dir -Icommon -c ${stem}.gen.c"
	echo "	mv ${root}.gen.\$(OBJEXT) \$@"
	;;

*/*.c)
	root=`basename $file .c`
	stem=`echo $file | sed 's/\.c$//'`
	dir=`echo $file | sed 's|/.*||'`

	if [ -n "$depfile" -a -r "$depfile" ]; then
		dep=`cat $depfile`
	fi

	if [ ${root} = option ]
	then
		libdir="-D'LIBDIR=\"\$(libdir)\"'"
	fi

	echo ""
	echo "${stem}.\$(OBJEXT): $file" $dep
	echo "	\$(CC) \$(CPPFLAGS) \$(CFLAGS)" $libdir "-I$dir -Icommon -c $file"
	echo "	mv ${root}.\$(OBJEXT) \$@"
	;;

man1/*.1)
	root=`basename $file .1`
	echo ""
	echo "man1/$root.h: $file etc/txt2c.awk"
	echo "	awk -f etc/txt2c.awk $file > \$@"

	echo ""
	echo "\$(mandir)/man1/$root.1: $file man1/.mandir"
	echo "	\$(SOELIM) -Iman1 $file > tmp"
	echo "	\$(INSTALL_DATA) tmp \$@"
	echo "	@rm tmp"
	;;

man1/*.so)
	root=`basename $file .so`
	echo ""
	echo "man1/$root.h: $file etc/txt2c.awk"
	echo "	awk -f etc/txt2c.awk $file > \$@"
	;;

test/*/*)
	root=`basename $file .sh`
	echo ""
	echo "$root: $file all"
	echo "	\$(SH) $file"
	;;

*)
	;;
esac
exit 0
